package com.op.wms.service;

import java.util.List;
import com.op.wms.domain.BaseWarehouse;

/**
 * 仓库管理Service接口
 * 
 * @author Open Platform
 * @date 2023-07-04
 */
public interface IBaseWarehouseService {
	/**
	 * 查询仓库管理
	 * 
	 * @param warehouseId 仓库管理主键
	 * @return 仓库管理
	 */
	public BaseWarehouse selectBaseWarehouseByWarehouseId(String warehouseId);

	/**
	 * 查询仓库管理列表
	 * 
	 * @param baseWarehouse 仓库管理
	 * @return 仓库管理集合
	 */
	public List<BaseWarehouse> selectBaseWarehouseList(BaseWarehouse baseWarehouse);

	/**
	 * 新增仓库管理
	 * 
	 * @param baseWarehouse 仓库管理
	 * @return 结果
	 */
	public int insertBaseWarehouse(BaseWarehouse baseWarehouse);

	/**
	 * 修改仓库管理
	 * 
	 * @param baseWarehouse 仓库管理
	 * @return 结果
	 */
	public int updateBaseWarehouse(BaseWarehouse baseWarehouse);

	/**
	 * 批量删除仓库管理
	 * 
	 * @param warehouseIds 需要删除的仓库管理主键集合
	 * @return 结果
	 */
	public int deleteBaseWarehouseByWarehouseIds(String[] warehouseIds);

	/**
	 * 删除仓库管理信息
	 * 
	 * @param warehouseId 仓库管理主键
	 * @return 结果
	 */
	public int deleteBaseWarehouseByWarehouseId(String warehouseId);
}
